%if 0%{?el8}
%ifarch s390x
# ConnectionTest fails
%bcond_with tests
%else
%bcond_without tests
%endif
%else
%bcond_without tests
%endif

%global _firewalld_dir %{_prefix}/lib/firewalld

Name:           et
Version:        6.1.7
Release:        1%{?dist}
Summary:        Remote shell that survives IP roaming and disconnect

License:        ASL 2.0
URL:            https://mistertea.github.io/EternalTerminal/
Source0:        https://github.com/MisterTea/EternalTerminal/archive/et-v%{version}.tar.gz
Source1:        et.xml
# SIGSTKSZ is no longer constant in glibc > 2.33 but a function returning a long
# cast the result before taking max
Patch0:         et-6.1.4-fix-sentry-breakpad-sigstksz.patch
# ditto with MINSIGSTKSZ
Patch1:         et-6.1.4-fix-catch2-minsigstksz.patch

BuildRequires:  boost-devel
BuildRequires:  cmake3
BuildRequires:  firewalld-filesystem
BuildRequires:  gcc-c++
BuildRequires:  gflags-devel
BuildRequires:  libatomic
BuildRequires:  libcurl-devel
BuildRequires:  libsodium-devel
BuildRequires:  libutempter-devel
BuildRequires:  ncurses-devel
BuildRequires:  openssl-devel
BuildRequires:  protobuf-compiler
BuildRequires:  protobuf-lite-devel
BuildRequires:  systemd

# Bundled libraries
Provides:       bundled(base64) = 0
# Catch2 is only a test framework
Provides:       bundled(cotire) = 1.8.0
Provides:       bundled(cpp-httplib) = 0.8.4
Provides:       bundled(cxxopts) = 2.2.0
Provides:       bundled(easyloggingpp) = 9.96.7
Provides:       bundled(msgpack) = 3.3.0
Provides:       bundled(nlohmann_json) = 3.9.1
Provides:       bundled(PlatformFolders) = 4.0.0
# sanitizers-cmake is only used when building
%ifnarch ppc64le s390x
Provides:       bundled(sentry-native) = 0.4.7
%endif
Provides:       bundled(simpleini) = 4.17
Provides:       bundled(sole) = 1.0.1
Provides:       bundled(ThreadPool) = 0
Provides:       bundled(UniversalStacktrace) = 0
# vcpkg is disabled


%{?systemd_requires}

%description
Eternal Terminal (ET) is a remote shell that automatically reconnects without
interrupting the session.


%prep
%autosetup -p1 -n EternalTerminal-et-v%{version}


%build
%cmake . \
%ifarch ppc64le s390x
  -DDISABLE_SENTRY=TRUE \
%endif
  -DDISABLE_VCPKG=TRUE
%cmake_build


%install
%cmake_install
mkdir -p \
  %{buildroot}%{_unitdir} \
  %{buildroot}%{_sysconfdir} \
  %{buildroot}%{_firewalld_dir}/services
install -m 0644 -p systemctl/et.service %{buildroot}%{_unitdir}/et.service
install -m 0644 -p etc/et.cfg %{buildroot}%{_sysconfdir}/et.cfg
install -m 0644 %{SOURCE1} %{buildroot}%{_firewalld_dir}/services/et.xml


%if %{with tests}
%check
%if 0%{?fedora}
%ctest
%else
%ctest --verbose
%endif
%endif


%post
%systemd_post et.service
%firewalld_reload

%preun
%systemd_preun et.service

%postun
%systemd_postun_with_restart et.service
%firewalld_reload


%files
%license LICENSE
%doc README.md
%{_bindir}/et
%{_bindir}/etserver
%{_bindir}/etterminal
%{_bindir}/htm
%{_bindir}/htmd
%dir %{_firewalld_dir}
%dir %{_firewalld_dir}/services
%{_firewalld_dir}/services/et.xml
%config(noreplace) %{_sysconfdir}/et.cfg
%{_unitdir}/et.service
# external dependency, used only for building
# once PlatformFolders is packaged, this can be removed
%exclude %{_includedir}/sago/platform_folders.h
%exclude %{_libdir}/cmake/platform_folders
%exclude %{_libdir}/libplatform_folders.a
%ifarch ppc64le s390x
%exclude %{_usr}/lib/debug/%{_libdir}/libplatform_folders.so-*.debug
%exclude %{_libdir}/libplatform_folders.so
%else
%exclude %{_libdir}/libplatform_folders.a
%endif


%changelog
* Mon Apr 26 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.1.7-1
- Update to 6.1.7

* Tue Mar 16 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.1.4-1
- Update to 6.1.4
- Fix for SIGSTKSZ/MINSIGSTKSZ non-constant on glibc > 2.33
- Declare bundled libraries

* Thu Nov 19 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.13-1
- Update to 6.0.13

* Thu Nov  5 2020 Filipe Brandenburger <filbranden@gmail.com> - 6.0.11-3
- Go back to using protobuf-lite on epel8, since the -devel package
  for it is now available (rhbz#1787458).

* Mon Aug  3 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.11-1
- Update to 6.0.11
- Use the new option to specify linking against the full protobuf on EPEL
- Adjust for cmake macro changes

* Tue Mar  3 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.7-1
- Update to 6.0.7

* Tue Feb 18 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.6-1
- Update to 6.0.6

* Sun Feb  2 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 6.0.5-1
- Initial build for EPEL 8
